##CBR Personas

Login as different users to see how the CBR content is displayed to different personas.

- <a href="javascript:cbr_user_data.login_as_guest_one()" >Persona One</a>
- <a href="javascript:cbr_user_data.login_as_guest_two()" >Persona Two</a>
- <a href="javascript:cbr_user_data.login_as_guest_three()" >Persona Three</a>

<webc-cbr-current-user></webc-cbr-current-user>